===========================
django-codenerix-pos-client
===========================

Codenerix POS Client is a module that enables the system where it is installed to communicate with POS module from `CODENERIX <https://www.codenerix.com/>`_

.. image:: https://github.com/codenerix/django-codenerix/raw/master/codenerix/static/codenerix/img/codenerix.png
    :target: https://www.codenerix.com
    :alt: Try our demo with Codenerix Cloud

****
Demo
****

Coming soon...

**********
Quickstart
**********

1. Install this package::

    For python 2: sudo pip2 install django-codenerix-pos-client
    For python 3: sudo pip3 install django-codenerix-pos-client

2. You are done, now you can work with your new command "codenerix_pos_client"

*************
Documentation
*************

Coming soon... do you help us?

You can get in touch with us `here <https://codenerix.com/contact/>`_.
